@@ -2,6 +2,7 @@ import os
 import sys
 import time
 from functools import partial
+import errno
 import hashlib
 
 from dateutil.parser import parse
@@ -13,6 +14,10 @@ from awscli.customizations.s3.utils import find_bucket_key, \
         guess_content_type, MD5Error
 
 
+class CreateDirectoryError(Exception):
+    pass
+
+
 def read_file(filename):
     """
     This reads the file into a form that can be sent to S3
@@ -34,8 +39,10 @@ def save_file(filename, response_data, last_update):
     try:
         if not os.path.exists(d):
             os.makedirs(d)
-    except Exception:
-        pass
+    except OSError as e:
+        if not e.errno == errno.EEXIST:
+            raise CreateDirectoryError(
+                "Could not create directory %s: %s" % (d, e))
     md5 = hashlib.md5()
     file_chunks = iter(partial(body.read, 1024 * 1024), b'')
     with open(filename, 'wb') as out_file:
